@@ -18,6 +18,7 @@ from lean.commands.cloud.live import live
 from lean.commands.cloud.optimize import optimize
 from lean.commands.cloud.pull import pull
 from lean.commands.cloud.push import push
+from lean.commands.cloud.status import status
 
 
 @click.group()
@@ -33,3 +34,4 @@ cloud.add_command(push)
 cloud.add_command(backtest)
 cloud.add_command(optimize)
 cloud.add_command(live)
+cloud.add_command(status)
