@@ -16,6 +16,7 @@ import click
 from lean.commands.config.get import get
 from lean.commands.config.list import list
 from lean.commands.config.set import set
+from lean.commands.config.unset import unset
 
 
 @click.group()
@@ -28,4 +29,5 @@ def config() -> None:
 
 config.add_command(get)
 config.add_command(set)
+config.add_command(unset)
 config.add_command(list)
